/*******************************************************************************
 **
 ** Licensed Materials - Property of IBM
 **
 ** (C) COPYRIGHT International Business Machines Corp. 2000, 2001
 ** All Rights Reserved.
 **
 ******************************************************************************/
#include "CLPAppUI.h"

void CCLPAppUi::ErrorNotify(TInt aErrCode, const TInt aErrMessage)
{   
  //*******************************************************************************
  //*** ErrorNotify(const TInt aMessageType, const TInt aError, TInt aErrCode 
  //*** MessageNotify(const TInt aMessageType, const TInt aMessage)
  //*** aMessageType - MSG_NOTICE, MSG_WARNING, ERR_OCCURED  
  //*******************************************************************************
  CEikonEnv::Static()->InfoWinL(aErrCode, aErrMessage);
}

void CCLPAppUi::MessageNotify(const TInt aMessageType, const TInt aMessage)
{
  //*******************************************************************************
  //*** ErrorNotify(const TInt aMessageType, const TInt aError, TInt aErrCode 
  //*** MessageNotify(const TInt aMessageType, const TInt aMessage)
  //*** aMessageType - MSG_NOTICE, MSG_WARNING, ERR_OCCURED  
  //*******************************************************************************
  CEikonEnv::Static()->InfoWinL(aMessageType, aMessage);
}

CCLPAppUi::~CCLPAppUi()
{   
  int rc = 0;
    
  if(iSplashView)
    delete iSplashView;
  
  if(iClpView)
    delete iClpView;
  
  RemoveFromStack(iAppView);
   
  if (iclpstate)
  {
    CLPStopEngine(iclpstate);
    free (iclpstate);
  }
}

/** CCLPAppUi::ConstructL() Definition
  */
void CCLPAppUi::ConstructL()
{
  int rc = 0;

  BaseConstructL();

  iRect = ClientRect();

  // set name label 
  SetNameLabelL();

  iCLPEng = CCLPEng::NewL(this);

  // initialize all the pointer
  iAppView = 0; 
  iSplashView = 0;
  iClpView = 0;

  iViewType = EViewNull; 
  iclpstate = 0;
 
  ConstructSplashViewL();
  LaunchLoginDlgL();     

  iIsSplashView=ETrue;
}

void CCLPAppUi::LaunchLoginDlgL()
{
  CEikDialog* dialog=new(ELeave) CLoginDlg(iSplashView, this, iRect);
  dialog->ExecuteLD(DLG_USER_LOGIN);
}

CLoginDlg::CLoginDlg(CCLPSplashView* aSplashView,
                     CCLPAppUi*      aAppUi,
                     TRect           aRect)
{
  iSplashView = aSplashView;
  iAppUi  = aAppUi;
  iRect = aRect;
  itemArray = 0; //initialize pointer
}

CLoginDlg::~CLoginDlg()
{
  if(itemArray)
    delete itemArray;
}

void CLoginDlg::PreLayoutDynInitL()
{
  
  // initialize user name
   CGlobalText* UserNameField = ((CEikGlobalTextEditor*) Control(EDlgLoginUserName))->GlobalText();
  
  // initialize password 
  // The text in the CEikSecretEditor control cannot be initialized; 
  // it must be entered directly by the user.

  //itemArray is member of class CLoginDlg and the memory
  //allocated in following part is released in its destructor
  itemArray=new(ELeave) CDesCArrayFlat(5);
  itemArray->AppendL(_L("C:\/System\/Data\/DB2e\/"));

  // set itemArray to display in comboBox
  CEikComboBox* comboBox=(CEikComboBox*)Control(EDlgLoginPath);
  comboBox->SetArray(itemArray,CEikComboBox::EArrayExternalOwner);
}

TBool CLoginDlg::OkToExitL(TInt aButtonId)
{
  switch(aButtonId)
  {
    case EEikBidOk:   // OK button
    {
      
      iAppUi->iUsername = _L("");
      iAppUi->iPassword = _L("");
      iAppUi->iPathname = _L("");

      // Get text from user name edwin
      GetEdwinText(iAppUi->iUsername,EDlgLoginUserName);

      // Get text from SecretEditor field
      GetSecretEditorText(iAppUi->iPassword,EDlgLoginPassword);

      // get text from comboBox
      CEikComboBox* comboBox=(CEikComboBox*)Control(EDlgLoginPath);
      comboBox->GetText(iAppUi->iPathname);

      iAppUi->ConstructSplashViewL();
     
    }
    break;

    case EEikBidCancel:   // Cancel button
      iAppUi->HandleCommandL(EEikCmdExit);
      return(EFalse);
      break;

  } //end switch(aButtonId)
  return(ETrue);
}

void CCLPAppUi::ConstructSplashViewL()
{
  if (iViewType==EViewClp || iViewType==EViewSplash)
  {
    RemoveFromStack(iAppView);
    iAppView->MakeVisible(EFalse);
  }

  if(iSplashView)
    delete iSplashView;

  iSplashView = new(ELeave) CCLPSplashView();
  iSplashView->ConstructL(iRect);
  iViewType=EViewSplash;
  iAppView=iSplashView;

  // add Splash View to stack and make visible 
  AddToStackL(iAppView);
  iAppView->MakeVisible(ETrue);
  iIsSplashView = ETrue;
}

void CCLPAppUi::ConstructClpViewL()
{
  int rc = 0;
  int i;
  // remove all objects form the stack
  if (iViewType==EViewSplash || iViewType==EViewClp)
  {
    RemoveFromStack(iAppView);
    iAppView->MakeVisible(EFalse);
  }

  if (iClpView)
    delete iClpView;

  iClpView = new(ELeave)CCLPView();

  if (!iclpstate)
  {
    iclpstate = (CLPState *) malloc(sizeof(CLPState));
    if (!iclpstate)
    {
      //CLPStdout(_TEXT(CLP_INTERNAL_ERROR2));
    }
    iclpstate->mode  = CLP_INTERACT;
    iclpstate->fpIN  = 0;
    iclpstate->fpOUT = 0;
     
    memset(iclpstate->sqlstate, 0, SQL_SQLSTATE_SIZE + 1);
    memset(iclpstate->err_string, 0, BUFSIZE);
    memset(iclpstate->cmd, 0, MAX_CMD_LEN);

    memset(iclpstate->msg, 0, MSGSIZE * sizeof(SQLTCHAR));
    memset(iclpstate->username, 0, SZUSERNAME);
    memset(iclpstate->password, 0, SZPASSWORD);
    memset(iclpstate->path, 0, SZPATH);

    memcpy(iclpstate->path, iPathname.PtrZ(), iPathname.Length()+1);
    for(i = 0; i < iPathname.Length(); i++)
    {
      if (iclpstate->path[i] == 16)
        iclpstate->path[i] = ' ';
    }

    memcpy(iclpstate->password, iPassword.PtrZ(), iPassword.Length()+1);
    for(i = 0; i < iPassword.Length(); i++)
    {
      if (iclpstate->password[i] == 16)
        iclpstate->password[i] = ' ';
    }

    memcpy(iclpstate->username, iUsername.PtrZ(), iUsername.Length()+1);
    for(i = 0; i < iPassword.Length(); i++)
    {
      if (iclpstate->username[i] == 16)
        iclpstate->username[i] = ' ';
    }

    // Start DB2 Everyplace engine
    rc = CLPStartEngine(iclpstate);
  
    if (rc)
    {
      if (iclpstate)
      {
        free(iclpstate);
        iclpstate = 0;
      }
    } 
  }
  
  iclpstate->epSupport = iCLPEng;
  iClpView->ConstructL(iRect, iclpstate, this);
  iViewType=EViewClp;
  iAppView=iClpView;

  // Add the application view onto the control stack so it can receive key press events
  AddToStackL(iAppView);
  iAppView->MakeVisible(ETrue);
  
  // Reset Boolean to disable CLP toolbar buttons
  iIsSplashView=EFalse;
}

void CCLPAppUi::SetNameLabelL()
{
  /********************************************************************************/
  /*** Display the application name at the top of the toolbar. First get the    ***/
  /*** control to display it in.                                                ***/
  /********************************************************************************/
  CEikFileNameLabel* filenameLabel=STATIC_CAST(CEikFileNameLabel*, 
                     iToolBar->ControlById(ECLPCmdFileName));
  /********************************************************************************/
  /***Then display the application name. UpdateL() displays the application's   ***/
  /*** main document file name in the filename label control. However, in this  ***/
  /*** application, there is no main document file (because the application is  ***/
  /*** not file based). In this case, UpdateL() displays the application name by***/
  /*** default.                                                                 ***/
  /********************************************************************************/
  filenameLabel->UpdateL();
}

void CCLPAppUi::ResetSplashViewL()
{
  ConstructSplashViewL();
}

/*********************************************************************/
/** Some commands in the toolbar/Tools menu prints an info message  **/
/** using the EIKON InfoMsg() function and calls CmdDialog() to     **/
/** create nd open a dialog.                                        **/
/*********************************************************************/
void CCLPAppUi::HandleCommandL(TInt aCommand)
{
 
  switch (aCommand)
  {
    case EEikCmdExit:
      iCoeEnv->Flush();
      CBaActiveScheduler::Exit();
      break;

    case CmdAboutCLP:
      ConstructSplashViewL();
      break;

    case CmdToolsClp:
      ConstructClpViewL();
      break;

    case CmdClpClear:
      if (!iIsSplashView)
        iClpView->HandleCommandL(CmdClpClear);
      else
        MessageNotify(MSG_NOTICE, MSG_OPEN_CLP_FIRST);
      break;

    case CmdRunSql:
      if (!iIsSplashView)
        iClpView->HandleCommandL(CmdRunSql);
      else
        MessageNotify(MSG_NOTICE, MSG_OPEN_CLP_FIRST);
    break;
  }
}

void CCLPAppUi::print1_ep(SQLTCHAR* msg)
{ 
  iClpView->PrintMsg(msg);
}
