/*******************************************************************************
 **
 ** Licensed Materials - Property of IBM
 **
 ** (C) COPYRIGHT International Business Machines Corp. 2000, 2001
 ** All Rights Reserved.
 **
 ******************************************************************************/
#include "CLPbitmap.h"

void TBitmapInfo::CheckPositions()
{
  iXPosition=Max(0, Min(iXPosition, 100-iXProportion));
  iYPosition=Max(0, Min(iYPosition, 100-iYProportion));
}

CBitmapControl::~CBitmapControl()
{
  delete iBitmap;
}

void CBitmapControl::ConstructL(const TDesC& aFileName, const TBitmapInfo& aBitmapInfo)
{
  iBitmapInfo=aBitmapInfo;
  iBitmap=iEikonEnv->CreateBitmapL(aFileName, 0);
}

TSize CBitmapControl::MinimumSize() const
{
  TSize bitmapSize=iBitmap->SizeInPixels();
  return TSize(bitmapSize.iWidth*iBitmapInfo.iXProportion/100,
               bitmapSize.iHeight*iBitmapInfo.iYProportion/100);
}

TSize CBitmapControl::MaximumSize() const
{
  return iBitmap->SizeInPixels();
}

void CBitmapControl::SetBitmapInfoL(const TBitmapInfo& aBitmapInfo)
{
  TBitmapInfo oldBitmapInfo=iBitmapInfo;
  iBitmapInfo=aBitmapInfo;
  if ((oldBitmapInfo.iXProportion != iBitmapInfo.iXProportion) ||
      (oldBitmapInfo.iYProportion != iBitmapInfo.iYProportion))
    SetSizeL(MinimumSize());
}

void CBitmapControl::Draw(const TRect& /*aRect*/) const
{
  CWindowGc& gc=SystemGc();
  TSize bitmapSize(iBitmap->SizeInPixels());
  TPoint bitmapTopLeft(bitmapSize.iWidth*iBitmapInfo.iXPosition/100,
                       bitmapSize.iHeight*iBitmapInfo.iYPosition/100);
  TSize bitmapVisibleSize(bitmapSize.iWidth*iBitmapInfo.iXProportion/100,
                          bitmapSize.iHeight*iBitmapInfo.iYProportion/100);
  TRect visibleRect(bitmapTopLeft, bitmapVisibleSize);
  gc.BitBlt(iPosition, iBitmap, visibleRect);
}
