/*******************************************************************************
 **
 ** Licensed Materials - Property of IBM
 **
 ** (C) COPYRIGHT International Business Machines Corp. 2000, 2001
 ** All Rights Reserved.
 **
 ******************************************************************************/

#include "CLPAppUI.h"


void CCLPAppUi::ErrorNotify(TInt aErrCode, const TInt aErrMessage)
{   
  CEikonEnv::Static()->InfoWinL(aErrCode, aErrMessage);
}


void CCLPAppUi::MessageNotify(const TInt aMessageType, const TInt aMessage)
{
  CEikonEnv::Static()->InfoWinL(aMessageType, aMessage);
}


CCLPAppUi::~CCLPAppUi()
{   
  if (iSplashView)
    delete iSplashView;
  
  if (iClpView)
    delete iClpView;
  
  RemoveFromStack(iAppView);
   
  if (iclpstate)
  {
    CLPStopEngine(iclpstate);
    free (iclpstate);
    iclpstate = NULL;
  }
}


void CCLPAppUi::ConstructL()
{
  BaseConstructL();

  iRect = ClientRect();

  // set name label 
  SetNameLabelL();

  iCLPEng = CCLPEng::NewL(this);

  // initialize all the pointer
  iAppView = 0; 
  iSplashView = 0;
  iClpView = 0;

  iViewType = EViewNull; 
  iclpstate = 0;
 
  ConstructSplashViewL();
  // LaunchLoginDlgL();     

  iIsSplashView=ETrue;
}


void CCLPAppUi::LaunchLoginDlgL()
{
  CEikDialog* dialog=new(ELeave) CLoginDlg(iSplashView, this, iRect);
  dialog->ExecuteLD(DLG_USER_LOGIN);
}


CLoginDlg::CLoginDlg(CCLPSplashView* aSplashView,
                     CCLPAppUi*      aAppUi,
                     TRect           aRect)
{
  iSplashView = aSplashView;
  iAppUi  = aAppUi;
  iRect = aRect;
  itemArray = 0; //initialize pointer
}


CLoginDlg::~CLoginDlg()
{
  //release pointer
  if (itemArray)
    delete itemArray;
}


void CLoginDlg::PreLayoutDynInitL()
{
  //itemArray is member of class CLoginDlg and the memory
  //allocated in following part is released in its destructor
  itemArray=new(ELeave) CDesCArrayFlat(5);
  itemArray->AppendL(_L("C:\\System\\Data\\DB2e\\"));  //xin

  // set itemArray to display in comboBox
  CEikComboBox* comboBox=(CEikComboBox*)Control(EDlgLoginPath);
  comboBox->SetArray(itemArray,CEikComboBox::EArrayExternalOwner);
}


TBool CLoginDlg::OkToExitL(TInt aButtonId)
{
  switch(aButtonId)
  {
    case EEikBidOk:   // OK button
    {
      TBuf<20> aUsername;
      TBuf<20> aPassword;
      TBuf<56> aPathname;
      
      iAppUi->iUsername = _L("");
      iAppUi->iPassword = _L("");
      iAppUi->iPathname = _L("");

      // Get text from user name edwin
      //rupesh GetEdwinText(iAppUi->iUsername,EDlgLoginUserName);

      // Get text from SecretEditor field
      //rupesh GetSecretEditorText(iAppUi->iPassword,EDlgLoginPassword);

      // get text from comboBox
      CEikComboBox* comboBox=(CEikComboBox*)Control(EDlgLoginPath);
      comboBox->GetText(iAppUi->iPathname);

      iAppUi->ConstructSplashViewL();
    }
    break;

    case EEikBidCancel:   // Cancel button
      iAppUi->HandleCommandL(EEikCmdExit);
      return(EFalse);
      break;

  } //end switch(aButtonId)

  return(ETrue);
}


void CCLPAppUi::ConstructSplashViewL()
{
  if (iViewType==EViewClp || iViewType==EViewSplash)
  {
    RemoveFromStack(iAppView);
    iAppView->MakeVisible(EFalse);
  }

  if (iSplashView)
    delete iSplashView;

  iSplashView = new(ELeave) CCLPSplashView();
  iSplashView->ConstructL(iRect);
   iViewType=EViewSplash;
  iAppView=iSplashView;

  //rupesh MenuBar()->ChangeMenuBarL(CLP_HOTKEYS,SPLASHVIEW_MENUBAR,EFalse);
  // add Splash View to stack and make visible 
  AddToStackL(iAppView);
  iAppView->MakeVisible(ETrue);
  iIsSplashView = ETrue;
}


void CCLPAppUi::ConstructClpViewL()
{
  int rc = 0;
  int i;

  // remove all objects form the stack
  if(iViewType==EViewSplash || iViewType==EViewClp)
  {
    RemoveFromStack(iAppView);
    iAppView->MakeVisible(EFalse);
  }

  if (iClpView)
    delete iClpView;

  iClpView = new(ELeave)CCLPView();

  if (!iclpstate)
  {
    iclpstate = (CLPState *) malloc(sizeof(CLPState));
    if (!iclpstate)
      goto error;

    iclpstate->mode  = CLP_INTERACT;
    iclpstate->fpIN  = 0;
    iclpstate->fpOUT = 0;
     
    memset(iclpstate->sqlstate, 0, SQL_SQLSTATE_SIZE + 1);
    memset(iclpstate->err_string, 0, BUFSIZE);
    memset(iclpstate->cmd, 0, MAX_CMD_LEN);

    memset(iclpstate->msg, 0, MSGSIZE * sizeof(SQLTCHAR));
/*rupesh
    memset(iclpstate->username, 0, 40);
    memset(iclpstate->password, 0, 40);
    memset(iclpstate->path, 0, 100);

    memcpy(iclpstate->path, iPathname.PtrZ(), iPathname.Length()+1);
    for(i = 0; i < iPathname.Length(); i++) {
      if (iclpstate->path[i] == 16)
        iclpstate->path[i] = ' ';
    }

    memcpy(iclpstate->password, iPassword.PtrZ(), iPassword.Length()+1);
    for(i = 0; i < iPassword.Length(); i++) {
      if (iclpstate->password[i] == 16)
        iclpstate->password[i] = ' ';
    }

    memcpy(iclpstate->username, iUsername.PtrZ(), iUsername.Length()+1);
    for (i = 0; i < iPassword.Length(); i++) {
      if (iclpstate->username[i] == 16)
        iclpstate->username[i] = ' ';
    }
*/

    // Start DB2 Everyplace engine
    rc = CLPStartEngine(iclpstate);
  
    if (rc) {
      free(iclpstate);
      iclpstate = 0;
      goto error;
    } 
  }

  iclpstate->epSupport = iCLPEng;

  iClpView->ConstructL(iRect, iclpstate, this);
  
  iViewType = EViewClp;
  iAppView  = iClpView;

  // Add the application view onto the control stack so it can receive key press events
  AddToStackL(iAppView);
  iAppView->MakeVisible(ETrue);
  
  // Reset Boolean to disable CLP toolbar buttons
  iIsSplashView=EFalse;

  // Change to Clp View custom menu
  //rupesh MenuBar()->ChangeMenuBarL(CLP_HOTKEYS,CLPVIEW_MENUBAR,EFalse);

  return;

error:
  delete iClpView;
  iClpView = NULL;
}


void CCLPAppUi::SetNameLabelL()
{
  /********************************************************************************/
  /*** Display the application name at the top of the toolbar. First get the    ***/
  /*** control to display it in.                                                ***/
  /********************************************************************************/
/* rupesh
  CEikFileNameLabel* filenameLabel=STATIC_CAST(CEikFileNameLabel*, 
                     iToolBar->ControlById(ECLPCmdFileName));
*/
  /********************************************************************************/
  /***Then display the application name. UpdateL() displays the application's   ***/
  /*** main document file name in the filename label control. However, in this  ***/
  /*** application, there is no main document file (because the application is  ***/
  /*** not file based). In this case, UpdateL() displays the application name by***/
  /*** default.                                                                 ***/
  /********************************************************************************/
 //rupesh filenameLabel->UpdateL();
}


void CCLPAppUi::ResetSplashViewL()
{
  ConstructSplashViewL();
}

/*********************************************************************/
/** Some commands in the toolbar/Tools menu prints an info message  **/
/** using the EIKON InfoMsg() function and calls CmdDialog() to     **/
/** create nd open a dialog.                                        **/
/*********************************************************************/

void CCLPAppUi::HandleCommandL(TInt aCommand)
{
  switch (aCommand)
  {
    case EEikCmdExit:
      iCoeEnv->Flush();
      CBaActiveScheduler::Exit();
      break;

    case CmdAboutCLP:
      ConstructSplashViewL();
      break;

    case CmdToolsClp:
      ConstructClpViewL();
      break;

    case CmdClpClear:
    
      if (!iIsSplashView)
        iClpView->HandleCommandL(CmdClpClear);
      else
        MessageNotify(MSG_NOTICE, MSG_OPEN_CLP_FIRST);
      break;

    case CmdRunSql:
      if (!iIsSplashView)
        iClpView->HandleCommandL(CmdRunSql);
      else
        MessageNotify(MSG_NOTICE, MSG_OPEN_CLP_FIRST);
      break;

    default:
      break;
  }
}


void CCLPAppUi::print1_ep(SQLTCHAR* msg)
{ 
  iClpView->PrintMsg(msg);
}
