/******************************************************************************/
/*   IBM Confidential                                                         */
/*                                                                            */
/*   OCO Source Materials.                                                    */
/*                                                                            */
/*   5622-388 (C) Copyright IBM Corp. 1999.                                   */
/*                                                                            */
/*   The source code for this program is not published or otherwise           */
/*   divested of its trade secrets, irrespective of what has been             */
/*   deposited with the U.S. Copyright Office.                                */
/*                                                                            */
/*   Product ID: 5648C61                                                      */
/******************************************************************************/
#include "memorw.h"

/*******************************************************************
/** pass in a category name to get back a category index. finds 
  * existing category, or adds new category if there is room, or 
  * returns unfiled if no more room.
  * @param  catName         name of the category to be created
  * @param  theDB           handle of database where to add the
  *                         new category
  * @return the index of newly added category                              
  */
 
int memo_AutoCat(char* catName, DmOpenRef theDB)
{
  VoidHand h = NULL;
  int foundCat;
  char seekCat[dmCategoryLength];
        
  // try to find category
  foundCat = CategoryFind(theDB, catName);
  if (foundCat == 255) {
      // look for an empty category slot
      for (foundCat = 0; foundCat < dmRecNumCategories;foundCat++) 
               {
                 CategoryGetName (theDB, foundCat, seekCat);
                 if (seekCat[0] == '\0')
                     break;
                }
                
      if (foundCat == dmRecNumCategories)
          return dmUnfiledCategory;
      // No more room for new categories
      // add new category
      CategorySetName (theDB, foundCat, catName);
                
      // lookup new category
      foundCat = CategoryFind(theDB, catName);
        }
      
   return foundCat;
}


//*********************************************************
char * memo_get_name(char *char_buff)
{
 char *str = NULL;
 int i; 
 
 i = 0; 
 while((char_buff[i] != '\n') && (i < StrLen(char_buff)))
 i++;

 str = (char *)MemPtrNew(sizeof(char) * (i+1));
 if(!str)
 	  return NULL;
 
 MemSet(str, sizeof(char)*(i+1), 0);
 MemMove(str, char_buff, i);	  
  //StrCopy(str, char_buff, i); 
  //don't know why this doesn't work

 return str; 
}

//***********************************************************
/*void MyPrintF(char*s,  char* formatstr, ...)
{
  va_list args;
  char text[100];
  //va_start(args, formatstr);  //compiling error ?!!
  StrVPrintF(text, formatstr, args);
  StrCopy(s, text);
  va_end(args);  
 }
*/
//***********************************************************
//the following two function haven't been used in SampleCLP.c
//for palm platform, so they are not implemented here.
int memoFeof(memoFILE* stream)
{
 int pos, allLen;
 VoidPtr memoHandle;
 char* memoPtr;
 
 memoHandle = *(stream->pMemoHandle);
 memoPtr  = MemHandleLock(memoHandle);
 allLen = StrLen(memoPtr); 
 pos = *(stream->pPos);
 
 MemHandleUnLock(memoHandle);
 if (pos >= allLen)
    return 1;
 else
    return 0;   
 
 }

int memoFflush(memoFILE* stream)
{ }

//***********************************************************
int memoFclose(memoFILE* stream)
{
  if(stream)
  {
   DmCloseDatabase(*(stream->pMemoRef));
   if(stream->pPos)
      MemPtrFree(stream->pPos);
   if(stream->pRec_id)
      MemPtrFree(stream->pRec_id);
   if(stream->pMemoRef)
      MemPtrFree(stream->pMemoRef);
   if(stream->pMemoHandle)
      MemPtrFree(stream->pMemoHandle);
        
   MemPtrFree(stream);
   return 0;
   }
   else
   return -1;        

}

//***********************************************************
memoFILE *memoFopen (char *filename, char *mode)
{
 LocalID   memoDBId;
 UInt16    memoCat;
 UInt16    memoId = 0;
 UInt16    numSQLmemos;
 VoidPtr   memoHandle;
 DmOpenRef memoRef;
 char*     memoPtr;
 char*     memoName = NULL;
 memoFILE  *pmemoFile = NULL;
 int       found = 0;
 
 //First allocat memory for memoFILE
   pmemoFile = (memoFILE *) MemPtrNew (sizeof(memoFILE));
   if(!pmemoFile)
     { //return failure
       ErrDisplay("Memory allocation failure.");
       return NULL;
      }
   else
     { //initialize structure
       MemSet(pmemoFile->memoName, DB2eCLP_MEMONAMESIZE, 0);
       MemSet(pmemoFile->mode, DB2eCLP_MEMOMODESIZE, 0);
       StrCopy(pmemoFile->memoName, filename);
       StrCopy(pmemoFile->mode, mode);
       pmemoFile->pPos = (int *)MemPtrNew(sizeof (int)); 
       *(pmemoFile->pPos) = StrLen(filename) + 1;// +1 for char '\n'
       pmemoFile->pRec_id = (int *)MemPtrNew(sizeof (int));
       *(pmemoFile->pRec_id) = -1; 
       pmemoFile->pMemoRef = (DmOpenRef *)MemPtrNew(sizeof (DmOpenRef));       
       pmemoFile->pMemoHandle = NULL;
      }
      
 // Do we have Memopad installed?
   memoDBId = DmFindDatabase(0, DB2eCLP_MEMODBNAME);
   if(!memoDBId)
   {
	  ErrDisplay("No such memo exists.");
	  return NULL ;
   }

   // Open the Memopad database
   // only for supporting "SampleCLP.c"
   if (!StrCompare(mode, "rb"))
      memoRef = DmOpenDatabase(0, memoDBId, dmModeReadOnly);
   else if (!StrCompare(mode, "wb+"))
      memoRef = DmOpenDatabase(0, memoDBId, dmModeReadWrite);
   *(pmemoFile->pMemoRef) = memoRef;
   
   // Is there an `SQL' memo category?
  /* memoCat = CategoryFind(memoRef, DB2eCLP_MEMOCATNAME);
   if(memoCat == dmAllCategories) 
   {
	  DmCloseDatabase(memoRef);
	  ErrDisplay("No such memo category exists.");
	  return NULL;
   }
  */
  memoCat = dmAllCategories;
  
   // Any SQL memos actually there?
 if(!StrCompare(mode, "rb"))
 {
    if(!(numSQLmemos = DmNumRecordsInCategory(memoRef, memoCat))) 
     {
	   DmCloseDatabase(memoRef);
	   ErrDisplay("No SQL commands text found!");
	   return NULL;
      }

   while (numSQLmemos--) 
   {
		  memoHandle = DmQueryNextInCategory(memoRef, &memoId, memoCat);
		  // Finally!  With memoPtr we're holding a pointer to an
		  // actual SQL memo in our hands...
		  memoPtr  = MemHandleLock(memoHandle);
	
		  // Now check if this is the memo we're looking for
		  // (compare memoName with content of first line in memo body)
		  //if(memoName)
		     //MemPtrFree(memoName);
      memoName = memo_get_name(memoPtr);
      MemHandleUnlock(memoHandle);
      
      if(!memoName)
      return NULL;
		  else if (!StrCompare(memoName, filename))
		   {		     
	       // Found it, now fill info to memoFile structure...
	       found = 1;
	       //MemHandleUnlock(memoHandle);
	       if(!pmemoFile->pMemoHandle)
	       pmemoFile->pMemoHandle = MemPtrNew(sizeof (VoidPtr));
           *(pmemoFile->pMemoHandle) = memoHandle;
           *(pmemoFile->pRec_id) = memoId;

   			if(memoName) //d2939 jcarrett
		      MemPtrFree(memoName); //d2939 jcarrett
           	       
	       break;
		  }
    
    if(memoName)
      MemPtrFree(memoName);
	  memoId++;
	  //MemHandleUnlock(memoHandle);
   }

   //if(memoName) //d2939 jcarrett
   //   MemPtrFree(memoName); //d2939 jcarrett  
   
   // No matching SQL memo found...
   if (!found) 
   return NULL;
   else
   return pmemoFile;
 }
 else
   return pmemoFile; 
   
}


//********************************************************
int memoFread(void* buffer,
			  int element_size,
			  int count,
			  memoFILE* stream)
{ 
 VoidPtr memoHandle;
 char* memoPtr;
 int pos, allLen, rsize = 0;
 
 memoHandle = *(stream->pMemoHandle);
 memoPtr  = MemHandleLock(memoHandle);
 pos = *(stream->pPos);
 allLen = StrLen(memoPtr);
 MemHandleUnlock(memoHandle);
 
 if(pos >= allLen)
 return -1; // come to the end of file
 
 if(pos + count > allLen)
     rsize = allLen - pos; 
 else
     rsize = count;
      
  
 MemSet(buffer, rsize, 0);
 MemMove(buffer, memoPtr + pos, rsize);
 pos += rsize;
 *(stream->pPos) = pos;

 //MemHandleUnlock(memoHandle);
 return rsize;
  
}

//********************************************************				
 int memoFwrite(char *buffer,
				int   element_size,
				int   count,
				memoFILE    *stream)
{ 
 DmOpenRef memoRef;
 VoidPtr memoHandle = NULL, newMemoHandle = NULL;
 VoidHand memoRec;
 VoidPtr memoPtr;
 int wsize = 0;
 UInt32 pos;
 unsigned short index; 
 int newMemoSize;
 char zero = 0;
 char a_line[1024] = {'\0'};
 UInt16 memoCat,attr = dmUnfiledCategory;

 pos = (UInt32)*(stream->pPos); 
 memoRef = *(stream->pMemoRef);
 
 if(stream->pMemoHandle)
    memoHandle = *(stream->pMemoHandle); 
   
 if((!memoHandle)||((memoHandle)&&(pos + count > DB2eCLP_MEMOSIZE)))
   {
    newMemoSize = DB2eCLP_MEMOSIZE * sizeof(char);
    index = DmNumRecords (memoRef);
    memoRec = DmNewRecord (memoRef, &index, newMemoSize); 
    *(stream->pRec_id) = index;
    
    newMemoHandle = MemHandleLock (memoRec);
    if(!(stream->pMemoHandle))
	     stream->pMemoHandle = MemPtrNew(sizeof (VoidPtr));
	  //*(stream->pMemoHandle) = newMemoHandle;
	  	
	 DmWrite(newMemoHandle, 0, &zero, sizeof(char)); 
   pos = 0;
   *(stream->pPos) = pos;
	 
	 //write memo name first
	 MemSet(a_line, 0, 1024); 
	 StrCopy(a_line, stream->memoName);
	 StrCat(a_line, "\n\0");
	 DmStrCopy (newMemoHandle,(*(stream->pPos)), a_line);
	 pos += (UInt32)StrLen(a_line);
	 (*(stream->pPos)) += StrLen(a_line);
	 
	 //then write the result 
	 if((memoHandle)&&(pos + count > DB2eCLP_MEMOSIZE))
	    wsize = DB2eCLP_MEMOSIZE - pos;
	 else
	    wsize = count;
	       
	 MemSet(a_line, 0, 1024);
	 StrNCopy(a_line, buffer, wsize); 
	 DmStrCopy (newMemoHandle,(*(stream->pPos)), a_line);
	 pos += (UInt32)wsize; 
	 (*(stream->pPos)) += wsize;
	 MemPtrUnlock (newMemoHandle);
	 *(stream->pMemoHandle) = newMemoHandle;
	 
	  // Is there an `SQL' memo category?
	  /*memoCat = CategoryFind(memoRef, DB2eCLP_MEMOCATNAME);
	  if(memoCat == dmAllCategories) 
	  {
	    DmCloseDatabase(memoRef);
		ErrDisplay("No such memo category exists.");
		return NULL;
      }
	 */
	 memoCat = dmAllCategories;
	 
	 // Set the category of the new record to the correct category.
	 DmRecordInfo (memoRef, index, &attr, NULL, NULL);
	 attr &= ~dmRecAttrCategoryMask;
	 if (memoCat != dmAllCategories)
	  	attr |= memoCat;
	 DmSetRecordInfo (memoRef, index, &attr, NULL);
	 DmReleaseRecord (memoRef, index, true);
   }
else
   {
     wsize = count; //should equal to count
     MemSet(a_line, 0, 1024);
	 StrNCopy(a_line, buffer, wsize); 
	 memoRec = DmGetRecord(memoRef, *(stream->pRec_id));
	 memoHandle = MemHandleLock (memoRec);
	 
	 DmStrCopy (memoHandle, (*(stream->pPos)), a_line);
	 (*(stream->pPos)) += wsize;
	 
	 MemPtrUnlock (memoHandle);
	 DmReleaseRecord(memoRef, *(stream->pRec_id), true);
    }
   
   return wsize; 
}





